var classIMP_1_1algebra_1_1SpherePatch3D =
[
    [ "SpherePatch3D", "classIMP_1_1algebra_1_1SpherePatch3D.html#a2925068c0cf5d0ad237c8bc63f70bd02", null ],
    [ "SpherePatch3D", "classIMP_1_1algebra_1_1SpherePatch3D.html#ae2287e153d7407b77aa454e4e838fa65", null ],
    [ "get_boundary_point", "classIMP_1_1algebra_1_1SpherePatch3D.html#afc6e12a3499bbc46394f7df0dc4e751d", null ],
    [ "get_contains", "classIMP_1_1algebra_1_1SpherePatch3D.html#a07f278aee7f47c8bf4b5113b3842c8d6", null ],
    [ "get_plane", "classIMP_1_1algebra_1_1SpherePatch3D.html#abf412d5eb9224b9db29943be84bb5f69", null ],
    [ "get_sphere", "classIMP_1_1algebra_1_1SpherePatch3D.html#a1dabd6f5edb8aa3295bf00461069a032", null ],
    [ "show", "classIMP_1_1algebra_1_1SpherePatch3D.html#a887c49fa757ad1e7ff1aca5a9a44bd06", null ]
];